@@ -34,11 +34,6 @@
 *  Developed by Arnaud Le Hors                                                *
 \*****************************************************************************/
 
-/*
- * The code related to FOR_MSW has been added by
- * HeDu (hedu@cul-ipn.uni-kiel.de) 4/94
- */
-
 #ifndef XPMI_h
 #define XPMI_h
 
@@ -52,18 +47,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <limits.h>
-/* stdio.h doesn't declare popen on a Sequent DYNIX OS */
-#ifdef sequent
-extern FILE *popen();
+#include <string.h>
+#if !defined(_MSC_VER)
+#include <strings.h>
 #endif
 
-#ifdef FOR_MSW
-#include "simx.h"
-#else
 #include <X11/Xos.h>
 #include <X11/Xfuncs.h>
 #include <X11/Xmd.h>
-#endif
 
 #ifdef VMS
 #include <unixio.h>
@@ -79,21 +70,11 @@ extern FILE *popen();
  */
 #define XpmFree(ptr) free(ptr)
 
-#ifndef FOR_MSW
 #define XpmMalloc(size) malloc((size))
 #define XpmRealloc(ptr, size) realloc((ptr), (size))
 #define XpmCalloc(nelem, elsize) calloc((nelem), (elsize))
-#else
-/* checks for mallocs bigger than 64K */
-#define XpmMalloc(size) boundCheckingMalloc((long)(size))/* in simx.[ch] */
-#define XpmRealloc(ptr, size) boundCheckingRealloc((ptr),(long)(size))
-#define XpmCalloc(nelem, elsize) \
-		boundCheckingCalloc((long)(nelem),(long) (elsize))
-#endif
 
-#if defined(SCO) || defined(__USLC__)
 #include <stdint.h>	/* For SIZE_MAX */
-#endif
 #include <limits.h>
 #ifndef SIZE_MAX
 # ifdef ULONG_MAX
@@ -103,6 +84,13 @@ extern FILE *popen();
 # endif
 #endif
 
+#ifdef O_CLOEXEC
+# define FOPEN_CLOEXEC "e"
+#else
+# define FOPEN_CLOEXEC ""
+# define O_CLOEXEC 0
+#endif
+
 #define XPMMAXCMTLEN BUFSIZ
 typedef struct {
     unsigned int type;
@@ -144,7 +132,7 @@ typedef struct {
     const char *Eoa;		/* string ending assignment */
 }      xpmDataType;
 
-extern xpmDataType xpmDataTypes[];
+extern _X_HIDDEN xpmDataType xpmDataTypes[];
 
 /*
  * rgb values and ascii names (from rgb text file) rgb values,
@@ -158,7 +146,7 @@ typedef struct {
 /* Maximum number of rgb mnemonics allowed in rgb text file. */
 #define MAX_RGBNAMES 1024
 
-extern const char *xpmColorKeys[];
+extern _X_HIDDEN const char *xpmColorKeys[];
 
 #define TRANSPARENT_COLOR "None"	/* this must be a string! */
 
@@ -167,35 +155,33 @@ extern const char *xpmColorKeys[];
 
 /* XPM internal routines */
 
-FUNC(xpmParseData, int, (xpmData *data, XpmImage *image, XpmInfo *info));
-FUNC(xpmParseDataAndCreate, int, (Display *display, xpmData *data,
+HFUNC(xpmParseData, int, (xpmData *data, XpmImage *image, XpmInfo *info));
+HFUNC(xpmParseDataAndCreate, int, (Display *display, xpmData *data,
 				  XImage **image_return,
 				  XImage **shapeimage_return,
 				  XpmImage *image, XpmInfo *info,
 				  XpmAttributes *attributes));
 
-FUNC(xpmFreeColorTable, void, (XpmColor *colorTable, int ncolors));
+HFUNC(xpmFreeColorTable, void, (XpmColor *colorTable, int ncolors));
 
-FUNC(xpmInitAttributes, void, (XpmAttributes *attributes));
+HFUNC(xpmInitAttributes, void, (XpmAttributes *attributes));
 
-FUNC(xpmInitXpmImage, void, (XpmImage *image));
+HFUNC(xpmInitXpmImage, void, (XpmImage *image));
 
-FUNC(xpmInitXpmInfo, void, (XpmInfo *info));
+HFUNC(xpmInitXpmInfo, void, (XpmInfo *info));
 
-FUNC(xpmSetInfoMask, void, (XpmInfo *info, XpmAttributes *attributes));
-FUNC(xpmSetInfo, void, (XpmInfo *info, XpmAttributes *attributes));
-FUNC(xpmSetAttributes, void, (XpmAttributes *attributes, XpmImage *image,
+HFUNC(xpmSetInfoMask, void, (XpmInfo *info, XpmAttributes *attributes));
+HFUNC(xpmSetInfo, void, (XpmInfo *info, XpmAttributes *attributes));
+HFUNC(xpmSetAttributes, void, (XpmAttributes *attributes, XpmImage *image,
 			      XpmInfo *info));
 
-#if !defined(FOR_MSW) && !defined(AMIGA)
-FUNC(xpmCreatePixmapFromImage, void, (Display *display, Drawable d,
+HFUNC(xpmCreatePixmapFromImage, int, (Display *display, Drawable d,
 				      XImage *ximage, Pixmap *pixmap_return));
 
-FUNC(xpmCreateImageFromPixmap, void, (Display *display, Pixmap pixmap,
+HFUNC(xpmCreateImageFromPixmap, void, (Display *display, Pixmap pixmap,
 				      XImage **ximage_return,
 				      unsigned int *width,
 				      unsigned int *height));
-#endif
 
 /* structures and functions related to hastable code */
 
@@ -211,10 +197,10 @@ typedef struct {
     xpmHashAtom *atomTable;
 }      xpmHashTable;
 
-FUNC(xpmHashTableInit, int, (xpmHashTable *table));
-FUNC(xpmHashTableFree, void, (xpmHashTable *table));
-FUNC(xpmHashSlot, xpmHashAtom *, (xpmHashTable *table, char *s));
-FUNC(xpmHashIntern, int, (xpmHashTable *table, char *tag, void *data));
+HFUNC(xpmHashTableInit, int, (xpmHashTable *table));
+HFUNC(xpmHashTableFree, void, (xpmHashTable *table));
+HFUNC(xpmHashSlot, xpmHashAtom *, (xpmHashTable *table, char *s));
+HFUNC(xpmHashIntern, int, (xpmHashTable *table, char *tag, void *data));
 
 #if defined(_MSC_VER) && defined(_M_X64)
 #define HashAtomData(i) ((void *)(long long)i)
@@ -227,45 +213,41 @@ FUNC(xpmHashIntern, int, (xpmHashTable *table, char *tag, void *data));
 
 /* I/O utility */
 
-FUNC(xpmNextString, int, (xpmData *mdata));
-FUNC(xpmNextUI, int, (xpmData *mdata, unsigned int *ui_return));
-FUNC(xpmGetString, int, (xpmData *mdata, char **sptr, unsigned int *l));
+HFUNC(xpmNextString, int, (xpmData *mdata));
+HFUNC(xpmNextUI, int, (xpmData *mdata, unsigned int *ui_return));
+HFUNC(xpmGetString, int, (xpmData *mdata, char **sptr, unsigned int *l));
 
 #define xpmGetC(mdata) \
 	((!mdata->type || mdata->type == XPMBUFFER) ? \
 	 (*mdata->cptr++) : (getc(mdata->stream.file)))
 
-FUNC(xpmNextWord, unsigned int,
+HFUNC(xpmNextWord, unsigned int,
      (xpmData *mdata, char *buf, unsigned int buflen));
-FUNC(xpmGetCmt, int, (xpmData *mdata, char **cmt));
-FUNC(xpmParseHeader, int, (xpmData *mdata));
-FUNC(xpmParseValues, int, (xpmData *data, unsigned int *width,
+HFUNC(xpmGetCmt, int, (xpmData *mdata, char **cmt));
+HFUNC(xpmParseHeader, int, (xpmData *mdata));
+HFUNC(xpmParseValues, int, (xpmData *data, unsigned int *width,
 			   unsigned int *height, unsigned int *ncolors,
 			   unsigned int *cpp, unsigned int *x_hotspot,
 			   unsigned int *y_hotspot, unsigned int *hotspot,
 			   unsigned int *extensions));
 
-FUNC(xpmParseColors, int, (xpmData *data, unsigned int ncolors,
+HFUNC(xpmParseColors, int, (xpmData *data, unsigned int ncolors,
 			   unsigned int cpp, XpmColor **colorTablePtr,
 			   xpmHashTable *hashtable));
 
-FUNC(xpmParseExtensions, int, (xpmData *data, XpmExtension **extensions,
+HFUNC(xpmParseExtensions, int, (xpmData *data, XpmExtension **extensions,
 			       unsigned int *nextensions));
 
 /* RGB utility */
 
-FUNC(xpmReadRgbNames, int, (char *rgb_fname, xpmRgbName *rgbn));
-FUNC(xpmGetRgbName, char *, (xpmRgbName *rgbn, int rgbn_max,
+HFUNC(xpmReadRgbNames, int, (const char *rgb_fname, xpmRgbName *rgbn));
+HFUNC(xpmGetRgbName, char *, (xpmRgbName *rgbn, int rgbn_max,
 			     int red, int green, int blue));
-FUNC(xpmFreeRgbNames, void, (xpmRgbName *rgbn, int rgbn_max));
-#ifdef FOR_MSW
-FUNC(xpmGetRGBfromName,int, (char *name, int *r, int *g, int *b));
-#endif
+HFUNC(xpmFreeRgbNames, void, (xpmRgbName *rgbn, int rgbn_max));
 
-#ifndef AMIGA
-FUNC(xpm_xynormalizeimagebits, void, (register unsigned char *bp,
+HFUNC(xpm_xynormalizeimagebits, void, (register unsigned char *bp,
 				      register XImage *img));
-FUNC(xpm_znormalizeimagebits, void, (register unsigned char *bp,
+HFUNC(xpm_znormalizeimagebits, void, (register unsigned char *bp,
 				     register XImage *img));
 
 /*
@@ -310,25 +292,8 @@ FUNC(xpm_znormalizeimagebits, void, (register unsigned char *bp,
 #define ZINDEX8(x, y, img) ((y) * img->bytes_per_line) + (x)
 
 #define ZINDEX1(x, y, img) ((y) * img->bytes_per_line) + ((x) >> 3)
-#endif /* not AMIGA */
 
-#ifdef NEED_STRDUP
-FUNC(xpmstrdup, char *, (char *s1));
-#else
-#undef xpmstrdup
-#define xpmstrdup strdup
-#include <string.h>
-#endif
-
-#ifdef NEED_STRCASECMP
-FUNC(xpmstrcasecmp, int, (char *s1, char *s2));
-#else
-#undef xpmstrcasecmp
-#define xpmstrcasecmp strcasecmp
-#include <strings.h>
-#endif
-
-FUNC(xpmatoui, unsigned int,
+HFUNC(xpmatoui, unsigned int,
      (char *p, unsigned int l, unsigned int *ui_return));
 
 #endif
