@@ -33,16 +33,6 @@
 *  Developed by Arnaud Le Hors                                                *
 \*****************************************************************************/
 
-/*
- * The code related to FOR_MSW has been added by
- * HeDu (hedu@cul-ipn.uni-kiel.de) 4/94
- */
-
-/*
- * The code related to AMIGA has been added by
- * Lorens Younes (d93-hyo@nada.kth.se) 4/96
- */
-
 /* October 2004, source code review by Thomas Biege <thomas@suse.de> */
 
 #ifdef HAVE_CONFIG_H
@@ -51,6 +41,10 @@
 #include "XpmI.h"
 #include <ctype.h>
 
+#if defined(_MSC_VER)
+#define strcasecmp _stricmp
+#endif
+
 LFUNC(xpmVisualType, int, (Visual *visual));
 
 LFUNC(AllocColor, int, (Display *display, Colormap colormap,
@@ -58,16 +52,12 @@ LFUNC(AllocColor, int, (Display *display, Colormap colormap,
 LFUNC(FreeColors, int, (Display *display, Colormap colormap,
 			Pixel *pixels, int n, void *closure));
 
-#ifndef FOR_MSW
 LFUNC(SetCloseColor, int, (Display *display, Colormap colormap,
 			   Visual *visual, XColor *col,
 			   Pixel *image_pixel, Pixel *mask_pixel,
 			   Pixel *alloc_pixels, unsigned int *nalloc_pixels,
 			   XpmAttributes *attributes, XColor *cols, int ncols,
 			   XpmAllocColorFunc allocColor, void *closure));
-#else
-/* let the window system take care of close colors */
-#endif
 
 LFUNC(SetColor, int, (Display *display, Colormap colormap, Visual *visual,
 		      char *colorname, unsigned int color_index,
@@ -89,24 +79,13 @@ LFUNC(CreateColors, int, (Display *display, XpmAttributes *attributes,
                           Pixel *alloc_pixels, unsigned int *nalloc_pixels,
                           Pixel *used_pixels, unsigned int *nused_pixels));
 
-#ifndef FOR_MSW
 LFUNC(ParseAndPutPixels, int, (xpmData *data, unsigned int width,
 			       unsigned int height, unsigned int ncolors,
 			       unsigned int cpp, XpmColor *colorTable,
 			       xpmHashTable *hashtable,
 			       XImage *image, Pixel *image_pixels,
 			       XImage *mask, Pixel *mask_pixels));
-#else  /* FOR_MSW */
-LFUNC(ParseAndPutPixels, int, (Display *dc, xpmData *data, unsigned int width,
-			       unsigned int height, unsigned int ncolors,
-			       unsigned int cpp, XpmColor *colorTable,
-			       xpmHashTable *hashtable,
-			       XImage *image, Pixel *image_pixels,
-			       XImage *mask, Pixel *mask_pixels));
-#endif
 
-#ifndef FOR_MSW
-# ifndef AMIGA
 /* XImage pixel routines */
 LFUNC(PutImagePixels, void, (XImage *image, unsigned int width,
 			     unsigned int height, unsigned int *pixelindex,
@@ -141,53 +120,12 @@ LFUNC(PutPixel8, int, (XImage *ximage, int x, int y, unsigned long pixel));
 LFUNC(PutPixel1MSB, int, (XImage *ximage, int x, int y, unsigned long pixel));
 LFUNC(PutPixel1LSB, int, (XImage *ximage, int x, int y, unsigned long pixel));
 
-# else /* AMIGA */
-LFUNC(APutImagePixels, void, (XImage *ximage, unsigned int width,
-			      unsigned int height, unsigned int *pixelindex,
-			      Pixel *pixels));
-# endif/* AMIGA */
-#else  /* FOR_MSW */
-/* FOR_MSW pixel routine */
-LFUNC(MSWPutImagePixels, void, (Display *dc, XImage *image,
-				unsigned int width, unsigned int height,
-				unsigned int *pixelindex, Pixel *pixels));
-#endif /* FOR_MSW */
-
-#ifdef NEED_STRCASECMP
-FUNC(xpmstrcasecmp, int, (char *s1, char *s2));
-
-/*
- * in case strcasecmp is not provided by the system here is one
- * which does the trick
- */
-int
-xpmstrcasecmp(
-    register char	*s1,
-    register char	*s2)
-{
-    register int c1, c2;
-
-    while (*s1 && *s2) {
-	c1 = tolower(*s1);
-	c2 = tolower(*s2);
-	if (c1 != c2)
-	    return (c1 - c2);
-	s1++;
-	s2++;
-    }
-    return (int) (*s1 - *s2);
-}
-
-#endif
-
 /*
  * return the default color key related to the given visual
  */
 static int
 xpmVisualType(Visual *visual)
 {
-#ifndef FOR_MSW
-# ifndef AMIGA
     switch (visual->class) {
     case StaticGray:
     case GrayScale:
@@ -202,14 +140,6 @@ xpmVisualType(Visual *visual)
     default:
 	return (XPM_COLOR);
     }
-# else
-    /* set the key explicitly in the XpmAttributes to override this */
-    return (XPM_COLOR);
-# endif
-#else
-    /* there should be a similar switch for MSW */
-    return (XPM_COLOR);
-#endif
 }
 
 
@@ -249,7 +179,6 @@ AllocColor(
 }
 
 
-#ifndef FOR_MSW
 /*
  * set a close color in case the exact one can't be set
  * return 0 if success, 1 otherwise.
@@ -429,10 +358,6 @@ SetCloseColor(
       || attributes->green_closeness != 0 \
       || attributes->blue_closeness != 0)))
 
-#else
-    /* FOR_MSW part */
-    /* nothing to do here, the window system does it */
-#endif
 
 /*
  * set the color pixel related to the given colorname,
@@ -462,13 +387,12 @@ SetColor(
     XColor xcolor;
     int status;
 
-    if (xpmstrcasecmp(colorname, TRANSPARENT_COLOR)) {
+    if (strcasecmp(colorname, TRANSPARENT_COLOR)) {
 	status = (*allocColor)(display, colormap, colorname, &xcolor, closure);
 	if (status < 0)		/* parse color failed */
 	    return (1);
 
 	if (status == 0) {
-#ifndef FOR_MSW
 	    if (USE_CLOSECOLOR)
 		return (SetCloseColor(display, colormap, visual, &xcolor,
 				      image_pixel, mask_pixel,
@@ -476,24 +400,15 @@ SetColor(
 				      attributes, cols, ncols,
 				      allocColor, closure));
 	    else
-#endif /* ndef FOR_MSW */
 		return (1);
 	} else
 	    alloc_pixels[(*nalloc_pixels)++] = xcolor.pixel;
 	*image_pixel = xcolor.pixel;
-#ifndef FOR_MSW
 	*mask_pixel = 1;
-#else
-	*mask_pixel = RGB(0,0,0);
-#endif
 	used_pixels[(*nused_pixels)++] = xcolor.pixel;
     } else {
 	*image_pixel = 0;
-#ifndef FOR_MSW
 	*mask_pixel = 0;
-#else
-  	*mask_pixel = RGB(255,255,255);
-#endif
 	/* store the color table index */
 	*mask_pixel_index = color_index;
     }
@@ -568,7 +483,6 @@ CreateColors(
     else
 	closure = NULL;
 
-#ifndef FOR_MSW
     if (USE_CLOSECOLOR) {
 	/* originally from SetCloseColor */
 #if 0
@@ -586,11 +500,7 @@ CreateColors(
 #endif
 	    unsigned int i;
 
-#ifndef AMIGA
 	    ncols = visual->map_entries;
-#else
-	    ncols = colormap->Count;
-#endif
 	    cols = (XColor *) XpmCalloc(ncols, sizeof(XColor));
 	    for (i = 0; i < ncols; ++i)
 		cols[i].pixel = i;
@@ -599,7 +509,6 @@ CreateColors(
 	}
 #endif
     }
-#endif /* ndef FOR_MSW */
 
     switch (key) {
     case XPM_MONO:
@@ -649,7 +558,7 @@ CreateColors(
 		    }
 		    if (def_index >= 2 && def_index <= 5 &&
 			defaults[def_index] != NULL &&
-			!xpmstrcasecmp(symbol->value, defaults[def_index]))
+			!strcasecmp(symbol->value, defaults[def_index]))
 			break;
 		}
 	    }
@@ -717,7 +626,7 @@ CreateColors(
 	    /* the following makes the mask to be built even if none
 	       is given a particular pixel */
 	    if (symbol->value
-		&& !xpmstrcasecmp(symbol->value, TRANSPARENT_COLOR)) {
+		&& !strcasecmp(symbol->value, TRANSPARENT_COLOR)) {
 		*mask_pixels = 0;
 		*mask_pixel_index = color;
 	    } else
@@ -859,9 +768,6 @@ XpmCreateImageFromXpmImage(
 	if (ErrorStatus != XpmSuccess)
 	    RETURN(ErrorStatus);
 
-#ifndef FOR_MSW
-# ifndef AMIGA
-
 	/*
 	 * set the ximage data using optimized functions for ZPixmap
 	 */
@@ -882,14 +788,6 @@ XpmCreateImageFromXpmImage(
 	else
 	    PutImagePixels(ximage, image->width, image->height,
 			   image->data, image_pixels);
-# else /* AMIGA */
-	APutImagePixels(ximage, image->width, image->height,
-			image->data, image_pixels);
-# endif
-#else  /* FOR_MSW */
-	MSWPutImagePixels(display, ximage, image->width, image->height,
-			  image->data, image_pixels);
-#endif
     }
     /* create the shape mask image */
     if (mask_pixel_index != XpmUndefPixel && shapeimage_return) {
@@ -898,18 +796,8 @@ XpmCreateImageFromXpmImage(
 	if (ErrorStatus != XpmSuccess)
 	    RETURN(ErrorStatus);
 
-#ifndef FOR_MSW
-# ifndef AMIGA
 	PutImagePixels1(shapeimage, image->width, image->height,
 			image->data, mask_pixels);
-# else /* AMIGA */
-	APutImagePixels(shapeimage, image->width, image->height,
-			image->data, mask_pixels);
-# endif
-#else  /* FOR_MSW */
-	MSWPutImagePixels(display, shapeimage, image->width, image->height,
-			  image->data, mask_pixels);
-#endif
 
     }
     XpmFree(image_pixels);
@@ -991,7 +879,6 @@ CreateXImage(
     if (!*image_return)
 	return (XpmNoMemory);
 
-#if !defined(FOR_MSW) && !defined(AMIGA)
     if (height != 0 && (*image_return)->bytes_per_line >= INT_MAX / height) {
 	XDestroyImage(*image_return);
 	*image_return = NULL;
@@ -1016,14 +903,9 @@ CreateXImage(
 	*image_return = NULL;
 	return (XpmNoMemory);
     }
-#else
-    /* under FOR_MSW and AMIGA XCreateImage has done it all */
-#endif
     return (XpmSuccess);
 }
 
-#ifndef FOR_MSW
-# ifndef AMIGA
 /*
  * The functions below are written from X11R5 MIT's code (XImUtil.c)
  *
@@ -1705,79 +1587,6 @@ XpmCreatePixmapFromXpmImage(
     return (ErrorStatus);
 }
 
-# else /* AMIGA */
-
-static void
-APutImagePixels (
-    XImage        *image,
-    unsigned int   width,
-    unsigned int   height,
-    unsigned int  *pixelindex,
-    Pixel         *pixels)
-{
-    unsigned int   *data = pixelindex;
-    unsigned int    x, y;
-    unsigned char  *array;
-    XImage         *tmp_img;
-    BOOL            success = FALSE;
-
-    array = XpmMalloc ((((width+15)>>4)<<4)*sizeof (*array));
-    if (array != NULL)
-    {
-	tmp_img = AllocXImage ((((width+15)>>4)<<4), 1,
-			       image->rp->BitMap->Depth);
-	if (tmp_img != NULL)
-	{
-	    for (y = 0; y < height; ++y)
-	    {
-		for (x = 0; x < width; ++x)
-		    array[x] = pixels[*(data++)];
-		WritePixelLine8 (image->rp, 0, y, width, array, tmp_img->rp);
-	    }
-	    FreeXImage (tmp_img);
-	    success = TRUE;
-	}
-	XpmFree (array);
-    }
-
-    if (!success)
-    {
-	for (y = 0; y < height; ++y)
-	    for (x = 0; x < width; ++x)
-		XPutPixel (image, x, y, pixels[*(data++)]);
-    }
-}
-
-# endif/* AMIGA */
-#else  /* FOR_MSW part follows */
-static void
-MSWPutImagePixels(
-    Display		*dc,
-    XImage		*image,
-    unsigned int	 width,
-    unsigned int	 height,
-    unsigned int	*pixelindex,
-    Pixel		*pixels)
-{
-    unsigned int *data = pixelindex;
-    unsigned int x, y;
-    HBITMAP obm;
-
-    obm = SelectObject(*dc, image->bitmap);
-    for (y = 0; y < height; y++) {
-	for (x = 0; x < width; x++) {
-	    SetPixel(*dc, x, y, pixels[*(data++)]); /* data is [x+y*width] */
-	}
-    }
-    SelectObject(*dc, obm);
-}
-
-#endif /* FOR_MSW */
-
-
-
-#if !defined(FOR_MSW) && !defined(AMIGA)
-
 static int
 PutPixel1(
     register XImage	*ximage,
@@ -1994,7 +1803,6 @@ PutPixel1LSB(
     return 1;
 }
 
-#endif /* not FOR_MSW && not AMIGA */
 
 /*
  * This function parses an Xpm file or data and directly create an XImage
@@ -2161,7 +1969,6 @@ xpmParseDataAndCreate(
 	if (ErrorStatus != XpmSuccess)
 	    RETURN(ErrorStatus);
 
-#if !defined(FOR_MSW) && !defined(AMIGA)
 
 	/*
 	 * set the XImage pointer function, to be used with XPutPixel,
@@ -2195,7 +2002,6 @@ xpmParseDataAndCreate(
 	    ximage->f.put_pixel = PutPixel1;
 	else
 	    ximage->f.put_pixel = PutPixel;
-#endif /* not FOR_MSW && not AMIGA */
     }
 
     /* create the shape mask image */
@@ -2205,22 +2011,16 @@ xpmParseDataAndCreate(
 	if (ErrorStatus != XpmSuccess)
 	    RETURN(ErrorStatus);
 
-#if !defined(FOR_MSW) && !defined(AMIGA)
 	if (shapeimage->bitmap_bit_order == MSBFirst)
 	    shapeimage->f.put_pixel = PutPixel1MSB;
 	else
 	    shapeimage->f.put_pixel = PutPixel1LSB;
-#endif
     }
 
     /*
      * read pixels and put them in the XImage
      */
-    ErrorStatus = ParseAndPutPixels(
-#ifdef FOR_MSW
-				    display,
-#endif
-				    data, width, height, ncolors, cpp,
+    ErrorStatus = ParseAndPutPixels(data, width, height, ncolors, cpp,
 				    colorTable, &hashtable,
 				    ximage, image_pixels,
 				    shapeimage, mask_pixels);
@@ -2337,9 +2137,6 @@ error:
 
 static int
 ParseAndPutPixels(
-#ifdef FOR_MSW
-    Display		*dc,
-#endif
     xpmData		*data,
     unsigned int	 width,
     unsigned int	 height,
@@ -2360,18 +2157,7 @@ ParseAndPutPixels(
 					 * colors */
 	{
 	    unsigned short colidx[256];
-#ifdef FOR_MSW
-	    HDC shapedc;
-	    HBITMAP obm, sobm;
 
-	    if ( shapeimage ) {
-		shapedc = CreateCompatibleDC(*dc);
-		sobm = SelectObject(shapedc, shapeimage->bitmap);
-	    } else {
-	        shapedc = NULL;
-	    }
-	    obm = SelectObject(*dc, image->bitmap);
-#endif
 	    if (ncolors > 256)
 		return (XpmFileInvalid);
 
@@ -2385,28 +2171,14 @@ ParseAndPutPixels(
 		    int c = xpmGetC(data);
 
 		    if (c > 0 && c < 256 && colidx[c] != 0) {
-#ifndef FOR_MSW
 			XPutPixel(image, x, y, image_pixels[colidx[c] - 1]);
 			if (shapeimage)
 			    XPutPixel(shapeimage, x, y,
 				      shape_pixels[colidx[c] - 1]);
-#else
-			SetPixel(*dc, x, y, image_pixels[colidx[c] - 1]);
-			if (shapedc) {
-			    SetPixel(shapedc, x, y, shape_pixels[colidx[c] - 1]);
-			}
-#endif
 		    } else
 			return (XpmFileInvalid);
 		}
 	    }
-#ifdef FOR_MSW
-	    if ( shapedc ) {
-	        SelectObject(shapedc, sobm);
-		DeleteDC(shapedc);
-	    }
-	    SelectObject(*dc, obm);
-#endif
 	}
 	break;
 
@@ -2444,21 +2216,11 @@ if (cidx[f]) XpmFree(cidx[f]);} while(0)
 			int cc2 = xpmGetC(data);
 			if (cc2 > 0 && cc2 < 256 &&
 			    cidx[cc1] && cidx[cc1][cc2] != 0) {
-#ifndef FOR_MSW
 			    XPutPixel(image, x, y,
 				      image_pixels[cidx[cc1][cc2] - 1]);
 			    if (shapeimage)
 				XPutPixel(shapeimage, x, y,
 					  shape_pixels[cidx[cc1][cc2] - 1]);
-#else
-			SelectObject(*dc, image->bitmap);
-			SetPixel(*dc, x, y, image_pixels[cidx[cc1][cc2] - 1]);
-			if (shapeimage) {
-			    SelectObject(*dc, shapeimage->bitmap);
-			    SetPixel(*dc, x, y,
-				     shape_pixels[cidx[cc1][cc2] - 1]);
-			}
-#endif
 			} else {
 			    FREE_CIDX;
 			    return (XpmFileInvalid);
@@ -2494,22 +2256,11 @@ if (cidx[f]) XpmFree(cidx[f]);} while(0)
 			slot = xpmHashSlot(hashtable, buf);
 			if (!*slot)	/* no color matches */
 			    return (XpmFileInvalid);
-#ifndef FOR_MSW
 			XPutPixel(image, x, y,
 				  image_pixels[HashColorIndex(slot)]);
 			if (shapeimage)
 			    XPutPixel(shapeimage, x, y,
 				      shape_pixels[HashColorIndex(slot)]);
-#else
-			SelectObject(*dc, image->bitmap);
-			SetPixel(*dc, x, y,
-				 image_pixels[HashColorIndex(slot)]);
-			if (shapeimage) {
-			    SelectObject(*dc, shapeimage->bitmap);
-			    SetPixel(*dc, x, y,
-				     shape_pixels[HashColorIndex(slot)]);
-			}
-#endif
 		    }
 		}
 	    } else {
@@ -2523,18 +2274,9 @@ if (cidx[f]) XpmFree(cidx[f]);} while(0)
 				break;
 			if (a == ncolors)	/* no color matches */
 			    return (XpmFileInvalid);
-#ifndef FOR_MSW
 			XPutPixel(image, x, y, image_pixels[a]);
 			if (shapeimage)
 			    XPutPixel(shapeimage, x, y, shape_pixels[a]);
-#else
-			SelectObject(*dc, image->bitmap);
-			SetPixel(*dc, x, y, image_pixels[a]);
-			if (shapeimage) {
-			    SelectObject(*dc, shapeimage->bitmap);
-			    SetPixel(*dc, x, y, shape_pixels[a]);
-			}
-#endif
 		    }
 		}
 	    }
